
/*
    This file is part of the 'yarec' package.
    Copyright (C) 1998  Ralf W. Stephan <stephan@tmt.de>

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
*/

#include "tasks/tasks.h"

#ifdef HAVE_SIGNAL_H

#include <signal.h>

void sigint_handler (void (*func)())
{
  struct sigaction new, old;
  new.sa_handler = func;
  sigemptyset(&new.sa_mask);
  new.sa_flags = 0;
  sigaction (SIGINT, &new, &old);
  if (old.sa_handler != SIG_IGN)
    sigaction (SIGINT, &new, 0);
}

void sigterm_handler (void (*func)())
{
  struct sigaction new, old;
  new.sa_handler = func;
  sigemptyset(&new.sa_mask);
  new.sa_flags = 0;
  sigaction (SIGTERM, &new, &old);
  if (old.sa_handler != SIG_IGN)
    sigaction (SIGTERM, &new, 0);
}

void sigpipe_handler (void (*func)())
{
  struct sigaction new, old;
  new.sa_handler = func;
  sigemptyset(&new.sa_mask);
  new.sa_flags = 0;
  sigaction (SIGPIPE, &new, &old);
  if (old.sa_handler != SIG_IGN)
    sigaction (SIGPIPE, &new, 0);
}

void sigsegv_handler (void (*func)())
{
  struct sigaction new, old;
  new.sa_handler = func;
  sigemptyset(&new.sa_mask);
  new.sa_flags = 0;
  sigaction (SIGSEGV, &new, &old);
  if (old.sa_handler != SIG_IGN)
    sigaction (SIGSEGV, &new, 0);
}

#else

void sigint_handler (void (*func)()) {}
void sigterm_handler (void (*func)()) {}
void sigpipe_handler (void (*func)()) {}

#endif
